==> apache-teaclave-0.2.0-incubating.tar.gz: apache-teaclave-0.2.0-rc.1-incubating/CONTRIBUTORS.md <==
---
permalink: /contributors
sidebar: false
---

# Contributors

Teaclave adopts [The Apache Way](https://www.apache.org/theapacheway/).
Everyone is more than welcome to contribute and make the project better.

## Mentors

Teaclave is now part of the Apache Incubator. We are fortunate to have the
following mentors.

- Felix Cheung
- Furkan Kamaci
- Jianyong Dai
- Luciano Resende (Retired)
- Matt Sicker
- Zhijie Shen

## Committers

Committers are people who have made substantial contribution to the project and
being active. In committers, the role of
[Podling Project Management Committee](https://incubator.apache.org/guides/ppmc.html)
(PPMC) is to help to govern the project and is directly responsible for the
oversight of Teaclave. Please contact the community if you'd like to become a
member of regular committers or PPMC of Teaclave.

- [Mingshen Sun](https://github.com/mssun) (PPMC)
- [Pei Wang](https://github.com/uraj) (PPMC)
- [Ran Duan](https://github.com/volcano0dr/)
- [Rundong Zhou](https://github.com/rdzhou) (PPMC)
- [Tao Wei](https://github.com/LenxWei) (PPMC)
- [Tongxin Li](https://github.com/litongxin1991) (PPMC)
- [Yiming Jing](https://github.com/kevinis) (PPMC)
- [Yu Ding](https://github.com/dingelish) (PPMC)
- [Yulong Zhang](https://github.com/yulongzhang) (PPMC)
- [Zhaofeng Chen](https://github.com/m4sterchain) (PPMC)

## Contributors

Teaclave is a community project and is very thankful for the many community
contributions it receives.

List of external contributors of Teaclave and Teaclave SGX SDK (in alphabetical order):
  - [Akhil Velagapudi](https://github.com/akhilles)
  - [Bing Duan](https://github.com/duanbing)
  - [BurtonQin](https://github.com/BurtonQin)
  - [Cheng XU](https://github.com/xu-cheng)
  - [David Phan](https://github.com/davidp94)
  - [Elichai Turkel](https://github.com/elichai)
  - [GeminiCarrie](https://github.com/GeminiCarrie)
  - [Greg Kapka](https://github.com/gskapka)
  - [Hongbin Mao](https://github.com/hello2mao)
  - [Jackson Owens](https://github.com/jbowens)
  - [Jimmy Casey](https://github.com/jimmycasey)
  - [Jun Jiang](https://github.com/jasl)
  - [LookForAdmin](https://github.com/60ke)
  - [Meng Yang](https://github.com/m3ngyang)
  - [Mengyuan-L](https://github.com/Mengyuan-L)
  - [Nick Hynes](https://github.com/nhynes)
  - [Qinkun Bao](https://github.com/qinkunbao)
  - [Raullen Chai](https://github.com/raullenchai)
  - [Sammy](https://github.com/sammyne)
  - [Shi Wenbin](https://github.com/bradyjoestar)
  - [Sythanos](https://github.com/sythanos)
  - [T0day](https://github.com/hi-T0day)
  - [Tianjia Zhang](https://github.com/uudiin)
  - [Zha0Chan](https://github.com/Zha0Chan)
  - [akoskinas](https://github.com/akoskinas)
  - [algon](https://github.com/algon-320)
  - [czzmmc](https://github.com/czzmmc)
  - [devashishdxt](https://github.com/devashishdxt)
  - [dtorfs](https://github.com/dtorfs)
  - [garbageslam](https://github.com/garbageslam)
  - [h4x3rotab](https://github.com/h4x3rotab)
  - [jknight](https://github.com/jknight)
  - [lhf](https://github.com/EighteenZi)
  - [luoyanhua2011](https://github.com/luoyanhua2011)
  - [lyj](https://github.com/lengyijun)
  - [piotr-roslaniec](https://github.com/piotr-roslaniec)
  - [rebol0x6c](https://github.com/rebol0x6c)
  - [volcano](https://github.com/volcano0dr)
  - [yc-huang](https://github.com/yc-huang)
  - [zEqueue](https://github.com/z1queue)

More people tracked in GitHub:
  - [Teaclave](https://github.com/apache/incubator-teaclave/graphs/contributors)
  - [Teaclave SGX SDK](https://github.com/apache/incubator-teaclave-sgx-sdk/graphs/contributors)

==> apache-teaclave-0.3.0-incubating.tar.gz: apache-teaclave-0.3.0-incubating/CONTRIBUTORS.md <==
---
permalink: /contributors
sidebar: false
---

# Contributors

Teaclave adopts [The Apache Way](https://www.apache.org/theapacheway/).
Everyone is more than welcome to contribute and make the project better.

## Mentors

Teaclave is now part of the Apache Incubator. We are fortunate to have the
following mentors.

- Felix Cheung
- Furkan Kamaci
- [Gordon King](https://github.com/bigdata-memory)
- Jianyong Dai
- Luciano Resende (Retired)
- Matt Sicker
- Zhijie Shen

## Committers

Committers are people who have made substantial contribution to the project and
being active. In committers, the role of
[Podling Project Management Committee](https://incubator.apache.org/guides/ppmc.html)
(PPMC) is to help to govern the project and is directly responsible for the
oversight of Teaclave. Please contact the community if you'd like to become a
member of regular committers or PPMC of Teaclave.

- [Mingshen Sun](https://github.com/mssun) (PPMC)
- [Pei Wang](https://github.com/uraj) (PPMC)
- [Rundong Zhou](https://github.com/rdzhou) (PPMC)
- [Tao Wei](https://github.com/LenxWei) (PPMC)
- [Tongxin Li](https://github.com/litongxin1991) (PPMC)
- [Yiming Jing](https://github.com/kevinis) (PPMC)
- [Yu Ding](https://github.com/dingelish) (PPMC)
- [Yulong Zhang](https://github.com/yulongzhang) (PPMC)
- [Zhaofeng Chen](https://github.com/m4sterchain) (PPMC)
- [Hongbo Chen](https://github.com/ya0guang)
- [Ran Duan](https://github.com/volcano0dr/)

## Contributors

Teaclave is a community project and is very thankful for the many community
contributions it receives.

List of external contributors of Teaclave, Teaclave SGX SDK, and Teaclave
TrustZone SDK (in alphabetical order):
  - [Akhil Velagapudi](https://github.com/akhilles)
  - [Bing Duan](https://github.com/duanbing)
  - [BruceFan](https://github.com/fanrong1992)
  - [BurtonQin](https://github.com/BurtonQin)
  - [Cheng XU](https://github.com/xu-cheng)
  - [David Phan](https://github.com/davidp94)
  - [Elichai Turkel](https://github.com/elichai)
  - [GeminiCarrie](https://github.com/GeminiCarrie)
  - [Greg Kapka](https://github.com/gskapka)
  - [He Sun](https://github.com/henrysun007)
  - [Hongbin Mao](https://github.com/hello2mao)
  - [Jackson Owens](https://github.com/jbowens)
  - [Jimmy Casey](https://github.com/jimmycasey)
  - [Jun Jiang](https://github.com/jasl)
  - [LookForAdmin](https://github.com/60ke)
  - [Meng Yang](https://github.com/m3ngyang)
  - [Mengyuan-L](https://github.com/Mengyuan-L)
  - [Nick Hynes](https://github.com/nhynes)
  - [Qinkun Bao](https://github.com/qinkunbao)
  - [Raullen Chai](https://github.com/raullenchai)
  - [Sammy](https://github.com/sammyne)
  - [Shi Wenbin](https://github.com/bradyjoestar)
  - [SimonWan](https://github.com/SimonWan)
  - [Sythanos](https://github.com/sythanos)
  - [T0day](https://github.com/hi-T0day)
  - [Tianjia Zhang](https://github.com/uudiin)
  - [Yuan Zhuang](https://github.com/DemesneGH)
  - [Zha0Chan](https://github.com/Zha0Chan)
  - [akoskinas](https://github.com/akoskinas)
  - [algon](https://github.com/algon-320)
  - [clauverjat](https://github.com/clauverjat)
  - [czzmmc](https://github.com/czzmmc)
  - [devashishdxt](https://github.com/devashishdxt)
  - [dtorfs](https://github.com/dtorfs)
  - [garbageslam](https://github.com/garbageslam)
  - [h4x3rotab](https://github.com/h4x3rotab)
  - [jknight](https://github.com/jknight)
  - [lhf](https://github.com/EighteenZi)
  - [luoyanhua2011](https://github.com/luoyanhua2011)
  - [lyj](https://github.com/lengyijun)
  - [piotr-roslaniec](https://github.com/piotr-roslaniec)
  - [rebol0x6c](https://github.com/rebol0x6c)
  - [volcano](https://github.com/volcano0dr)
  - [yc-huang](https://github.com/yc-huang)
  - [zEqueue](https://github.com/z1queue)

More people tracked in GitHub:
  - [Teaclave](https://github.com/apache/incubator-teaclave/graphs/contributors)
  - [Teaclave SGX SDK](https://github.com/apache/incubator-teaclave-sgx-sdk/graphs/contributors)
  - [Teaclave TrustZone SDK](https://github.com/apache/incubator-teaclave-trustzone-sdk/graphs/contributors)
